////////////////////////////////////////////////////////////////////////////////////////////
//   aio_admin.sma                   Version 2.0 Release                   Date: OCT/02/2004
//
//   RS All-In-One[AIO] Admin Menu
//   File: AIO Admin Base Source File
//
//   By:    Rob Secord
//   Alias: xeroblood (aka; sufferer)
//   Email: xeroblood@msn.com
//
//   Developed using:  AMX 0.9.9     &     AMXX 0.20
//   Modules:          Fun & Misc          Fun & Misc
//                     VexD-UM             Engine
//                                         CStrike
//   Tested On:        CS 1.6 (STEAM)
//                     Windows XP Professional
//
////////////////////////////////////////////////////////////////////////////////////////////
//   To Do:
//     - Add an OFF feature to the menu
//     - Team-Changer (Remove Admin-Editor)
//     - Llama Voice  (Replace Warn)
//     - Admins Without Immunity CANT Perform on self
//     - Change 'Warn' to 'Rules' Client Say Command (Add CVAR to show it on Connect)
//     -
//     -
//
////////////////////////////////////////////////////////////////////////////////////////////


#include "aio_inc/config.cfg"       // Pre-compilation Configurations
                                    // (Make Any Neccessary Changes To This File)

#if defined USE_AMXX_MODE
    #include <amxmodx>              // AMX Mod X 0.20 Base
    #include <engine>               // AMXX - Engine Module
    #include <cstrike>              // AMXX - CStrike Module
#else
    #include <amxmod>               // AMX Mod 0.9.9 Base
    #include <Vexd_Utilities>       // AMX - VexD Utilities Module
#endif
#include <amxmisc>                  // AMX/AMXX Misc Module
#include <fun>                      // AMX/AMXX Fun Module

// AIO Custom Includes
#include "aio_inc/const.inc"        // Constant Defines
#include "aio_inc/global.inc"       // Global Variables
#include "aio_inc/common.inc"       // Common Functions

#include "aio_inc/events.inc"       // Hooked Events
#include "aio_inc/commands.inc"     // Client Commands
#include "aio_inc/menus.inc"        // Client Menu System
#include "aio_inc/actions.inc"      // Command Actions
#include "aio_inc/effects.inc"      // Command Special Effects


public plugin_init()
{
    register_plugin( PLUGIN_NAME, PLUGIN_VERSION, PLUGIN_AUTHOR )

    // Client Commands
    register_clcmd( "aio_mode", "ClCmd_AIOMode", REQD_LEVEL, "<on|off> - Toggles AIO-Admin On/Off" )
    register_clcmd( "aio_help", "ClCmd_AIOHelp", REQD_LEVEL, "- Displays AIO-Admin Help Information (MOTD)" )
    register_clcmd( "aio_menu", "ClCmd_AIOMenu", REQD_LEVEL, "- Displays AIO-Admin Command Menu." )

    register_clcmd( "say",      "ClCmd_CheckSay" )
    register_clcmd( "say_team", "ClCmd_CheckSay" )

    for( new i = 0; i < MAX_COMMANDS; i++ )
        register_clcmd( g_szAdminCmd[i], "ClCmd_AdminCmd", REQD_LEVEL, "- Use aio_help Command for Usage." )

    // Registered Events
    register_event( "DeathMsg",  "Event_DeathMsg",  "a" )
    register_event( "ResetHUD",  "Event_NewRound",  "b" )
    register_event( "CurWeapon", "Event_ChgWeapon", "be", "1=1" )

    // Registered Menus
    register_menucmd( register_menuid("\yAIO Player Menu"),   1023, "Menu_AIONext" )
    register_menucmd( register_menuid("\yAIO Command Menu"),  1023, "Menu_AIONext" )
    register_menucmd( register_menuid("\yAIO Command Types"), 1023, "Menu_AIOType" )
    register_menucmd( register_menuid("\yAIO Settings Menu"), 1023, "Menu_AIOAction" )

    // Set Maximum Player Speed
    server_cmd( "sv_maxspeed 1000" )

    // Client Message Indexes
    g_nMsgDamage = get_user_msgid( "Damage" )
    g_nMsgDeath  = get_user_msgid( "DeathMsg" )

    // Plugin-Specific CVARs
    register_cvar( "sv_aio_allow",         "1" )
    register_cvar( "sv_aio_immunity_bad",  "1" )
    register_cvar( "sv_aio_immunity_good", "0" )
    register_cvar( "sv_aio_immunity_misc", "0" )
    register_cvar( "sv_aio_menu_start",    "1" )
    register_cvar( "sv_aio_command_flags", "abcdefghijklmnopqrstuvwxyz123456" )

    // Command-Specific CVARs
    register_cvar( "sv_aio_ban_ip",        "1" )    // 1=Ban IP, 0=Ban STEAM ID
    register_cvar( "sv_aio_fire_damage",   "5" )    // Fire Damage / Second
    register_cvar( "sv_aio_poison_damage", "5" )    // Poison Damage / Second
    register_cvar( "sv_aio_turbo_speed",   "1000" ) // Turbo Speed (Range 400 - 1000)

    // Menu-Specific CVARs [Max 9 Options / CVAR]
    register_cvar( "sv_aio_ban",    "0 15 30 60 90 120 300 600 1440" )
    register_cvar( "sv_aio_slap",   "1 5 10 15 20 25 50 75 99" )
    register_cvar( "sv_aio_bslap",  "10 20 30 40 50 60 70 80 90" )
    register_cvar( "sv_aio_gag",    "15 30 60 90 120 300 600 900 1200" )
    register_cvar( "sv_aio_mute",   "15 30 60 90 120 300 600 900 1200" )
    register_cvar( "sv_aio_blanks", "15 30 60 90 120 300 600 900 1200" )
    register_cvar( "sv_aio_fire",   "2 5 10 11 12 13 14 15 20" )
    register_cvar( "sv_aio_poison", "2 5 10 11 12 13 14 15 20" )
    register_cvar( "sv_aio_god",    "15 30 60 90 120 300 600 900 1200" )
    register_cvar( "sv_aio_grav",   "15 30 60 90 120 300 600 900 1200" )
    register_cvar( "sv_aio_noclip", "15 30 60 90 120 300 600 900 1200" )
    register_cvar( "sv_aio_turbo",  "15 30 60 90 120 300 600 900 1200" )
    register_cvar( "sv_aio_silent", "15 30 60 90 120 300 600 900 1200" )
    register_cvar( "sv_aio_invis",  "15 30 60 90 120 300 600 900 1200" )
    register_cvar( "sv_aio_spy",    "15 30 60 90 120 300 600 900 1200" )
    register_cvar( "sv_aio_nades",  "15 30 60 90 120 300 600 900 1200" )
    register_cvar( "sv_aio_ammo",   "15 30 60 90 120 300 600 900 1200" )
    register_cvar( "sv_aio_health", "25 50 75 100 125 150 175 200 255" )
    register_cvar( "sv_aio_armor",  "25 50 75 100 125 150 175 200 255" )
    register_cvar( "sv_aio_revive", "1 2 3 4 5 6 7 8 9" )
    register_cvar( "sv_aio_ears",   "15 30 60 90 120 300 600 900 1200" )
    register_cvar( "sv_aio_cash",   "0 800 1500 3000 6000 9000 12000 14000 16000" )
    register_cvar( "sv_aio_admin",  "ijm ijn ijo ijp ijq ijr ijs ijt abcde" )
    register_cvar( "sv_aio_frags",  "-3 -2 -1 1 2 3 4 5 6" )
    register_cvar( "sv_aio_weapon", "0 3 4 14 15 18 22 26 28" )
}

public plugin_cfg()
{
    BuildFileDirs()
    return PLUGIN_CONTINUE
}

public plugin_precache()
{
    g_sprWhite  = precache_model( "sprites/white.spr" )
    g_sprSmoke  = precache_model( "sprites/steam1.spr" )
    g_sprMFlash = precache_model( "sprites/muzzleflash.spr" )
    g_sprBFlare = precache_model( "sprites/blueflare2.spr" )

    precache_sound( g_szSndFlames )
    precache_sound( g_szSndScream1 )
    precache_sound( g_szSndScream2 )
    precache_sound( g_szSndRocket1 )
    precache_sound( g_szSndRocket2 )
    precache_sound( g_szSndPoison )

    return PLUGIN_CONTINUE
}

public client_authorized( id )
{
    g_nHasEffect[id-1] = 0
    g_nReviveTimes[id-1] = 0

    return PLUGIN_CONTINUE
}

public client_disconnect( id )
{
    g_nHasEffect[id-1] = 0
    g_nReviveTimes[id-1] = 0

    return PLUGIN_CONTINUE
}

#if defined USE_AMXX_MODE
public client_PreThink( id )
#else
public client_prethink( id )
#endif
{
    if( g_nHasEffect[id-1] & AIO_SILENT )
        entity_set_int( id, EV_INT_flTimeStepSound, 999 )

    return PLUGIN_CONTINUE
}

